==> fuselage-0.0.1.zip: fuselage-0.0.1/fuselage/tests/test_providers_apt.py <==
# Copyright 2013-2014 Isotoma Limited
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from fuselage.tests.base import TestCaseWithRunner
from fuselage.resources import Package
from fuselage import error


class TestApt(TestCaseWithRunner):

    def test_already_installed(self):
        self.bundle.add(Package(name="python"))
        self.assertRaises(error.NothingChanged, self.apply)

    def test_installation(self):
        self.bundle.add(Package(name="hello"))
        self.check_apply()
        self.failUnlessExists("/usr/bin/hello")

    def test_nonexistent_package(self):
        self.bundle.add(Package(name="zzzz"))
        self.assertRaises(error.AptError, self.apply)

    def test_package_reinstallation(self):
        p = self.bundle.add(Package(name="hello"))
        self.apply()
        self.failUnlessExists("/usr/bin/hello")

        p.policy = "uninstall"
        self.apply()
        self.failIfExists("/usr/bin/hello")

        p.policy = "install"
        self.apply()
        self.failUnlessExists("/usr/bin/hello")


class TestPackageRemoval(TestCaseWithRunner):

    def test_installed(self):
        self.bundle.add(Package(name="python", policy="uninstall"))
        self.check_apply()
        self.failIfExists("/usr/share/doc/python/copyright")

==> fuselage-0.0.11.zip: fuselage-0.0.11/fuselage/tests/test_providers_apt.py <==
# Copyright 2013-2014 Isotoma Limited
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from fuselage.tests.base import TestCaseWithRunner
from fuselage.resources import Package
from fuselage import error


class TestApt(TestCaseWithRunner):

    def test_already_installed(self):
        self.bundle.add(Package(name="python"))
        self.assertRaises(error.NothingChanged, self.apply)

    def test_installation(self):
        self.bundle.add(Package(name="hello"))
        self.check_apply()
        self.failUnlessExists("/usr/bin/hello")

    def test_nonexistent_package(self):
        self.bundle.add(Package(name="zzzz"))
        self.assertRaises(error.PackageError, self.apply)

    def test_package_reinstallation(self):
        p = self.bundle.add(Package(name="hello"))
        self.apply()
        self.failUnlessExists("/usr/bin/hello")

        p.policy = "uninstall"
        self.apply()
        self.failIfExists("/usr/bin/hello")

        p.policy = "install"
        self.apply()
        self.failUnlessExists("/usr/bin/hello")


class TestPackageRemoval(TestCaseWithRunner):

    def test_installed(self):
        self.bundle.add(Package(name="python", policy="uninstall"))
        self.check_apply()
        self.failIfExists("/usr/share/doc/python/copyright")
